BloomFilterer
=============

.. currentmodule:: pykeen.sampling.filtering

.. autoclass:: BloomFilterer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BloomFilterer.add
      ~BloomFilterer.contains
      ~BloomFilterer.num_bits
      ~BloomFilterer.num_probes
      ~BloomFilterer.probe

   .. rubric:: Methods Documentation

   .. automethod:: add
   .. automethod:: contains
   .. automethod:: num_bits
   .. automethod:: num_probes
   .. automethod:: probe
